# MyExternalOutputs.py

# datetime class page 303
# csv page 216
# txt page 206

# DateTime Module 4 widely used classes
# datetime YYYY-MM-DD HH:mm:ss.mmmmmm
# date YYYY-MM-DD 12:00:00.000000
# time just time
# timedelta calculated time  2024-08-15 + timedelta(days=30)

# page 309 datetime formats
import datetime as dt  # import module
# from module import object
# import module as namespace

orderDate = dt.datetime.now()
shipViaDate = orderDate + dt.timedelta(days=5)
print(f"Order Date: {orderDate} ")
print(f"Ship Via Date: {shipViaDate:%x}")
fmt_shipViaDate = f"{shipViaDate:%x}" # mm/dd/yyyy

order = ['1002', 'Jane', 'Doe', 100.50, orderDate, fmt_shipViaDate]

# IntelliSense Linting

# order to CSV procedures
import os
import csv

filename = "orders.csv" # datasource

# function to write a csv file based on the order
def write_order_to_csv(order, filename):
    # fieldnames
    # sample data
    # ['1001', 'Bob', 'Smith', 100.50, orderDate, fmt_shipViaDate]
    fieldnames = ['orderId', 'firstName', 'lastName', 'orderTotal', 'orderDate', 'fmt_shipViaDate']
    file_exists = os.path.isfile(filename) # boolean

    # open the filename
    # mode w will OVERRIDE all data
    # mode a append new data to the end
    # mode r reads a file
    # open() you have to manually close() the data stream
    # with open() close happends at the end of the operation
    with open(filename, 'a', newline='') as csvfile:
        writer = csv.DictWriter(csvfile, fieldnames=fieldnames)

        if not file_exists:
            writer.writeheader() # row[0] == Null fieldnames

        # for multiple orders pass into the functions orders, then use a for x in ys loop, with the writerow() in the loop
        # for order in orders:
        # SQL injector would replace writer
        writer.writerow({
            'orderId': order[0], 
            'firstName': order[1], 
            'lastName': order[2], 
            'orderTotal': order[3], 
            'orderDate': order[4], 
            'fmt_shipViaDate': order[5]
        })

# Example to write the order 1001
# call our write function
# write_order_to_csv(order, filename)

# Read data from a csv and merge with a txt file
# from moduleName import ObjectName
from string import Template

def read_order_from_csv(order_id, filename):
    with open(filename, 'r', newline='') as csvfile:
        reader = csv.DictReader(csvfile)
        # no need to define reading header line, DictReader() will do that for you
        # At this point we now have read row[0] as header/fieldnames and row[1:] as data rows
        for row in reader:
            if row['orderId'] == order_id: # input()
                return row
    return None  # return row if one exists



def generate_receipt(order_data):

    email_content = """
    <div>
<strong>Order Details:</strong><br>
--------------<br>
Order id: $orderId<br>
Customer: $firstName $lastName  <br>
Order Date: $orderDate    <br>
</div>                                           
"""
    receipt_output = Template(email_content)
    # tab1 receipt_output
    return receipt_output.substitute(order_data)    

# runtime
order_id = input("Enter an order id to generate a rcpt: ")
order_data = read_order_from_csv(order_id, filename)

if order_data:
    # we have a valid order 1001 or 1002
    email = generate_receipt(order_data)

    email_filename = f"emailReceipt_{order_id}.html"

    # create txt file
    with open(email_filename, 'w') as file:
        file.write(email)
else:
    print(f"No order found for {order_id}")
